package cz.muni.fi.pa165.dao;

import cz.muni.fi.pa165.PersistenceSampleApplicationContext;
import cz.muni.fi.pa165.dao.teamCoach.TeamCoachDao;
import cz.muni.fi.pa165.entity.TeamCoachEntity;
import cz.muni.fi.pa165.enums.CountryEnum;
import org.assertj.core.api.Assertions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.testng.AbstractTransactionalTestNGSpringContextTests;
import org.testng.annotations.Test;

import java.util.UUID;

import static org.assertj.core.api.AssertionsForClassTypes.assertThat;

/**
 * @author Adrian Piacek
 */
@ContextConfiguration(classes = PersistenceSampleApplicationContext.class)
public class TeamCoachDaoTest extends AbstractTransactionalTestNGSpringContextTests {

    @Autowired
    private TeamCoachDao coachDao;

    @Test
    void create() {
        TeamCoachEntity coach = new TeamCoachEntity("AutistaCoach");
        coachDao.create(coach);
        assertThat(coach.getId()).isNotNull();
        Assertions.assertThat(coachDao.findAll()).hasSize(1);
    }

    @Test
    void findByIdExisting() {
        TeamCoachEntity coach = new TeamCoachEntity("AutistaCoach");
        coachDao.create(coach);
        var find = coachDao.findById(coach.getId());
        assertThat(find).isEqualTo(coach);
    }

    @Test
    void findByIdNonExisting() {
        Assertions.assertThat(coachDao.findAll()).isEmpty();

        var find = coachDao.findById(UUID.randomUUID());
        assertThat(find).isNull();
    }

    @Test
    void findAll() {
        TeamCoachEntity coachA = new TeamCoachEntity("AutistaCoachA");
        TeamCoachEntity coachB = new TeamCoachEntity("AutistaCoachB");
        coachDao.create(coachA);
        coachDao.create(coachB);
        Assertions.assertThat(coachDao.findAll()).hasSize(2);
    }

    @Test
    void update() {
        TeamCoachEntity teamCoachEntity = new TeamCoachEntity("CoachA");
        coachDao.create(teamCoachEntity);
        teamCoachEntity.setCountry(CountryEnum.SLOVAKIA);
        coachDao.update(teamCoachEntity);
        Assertions.assertThat(coachDao.findById(teamCoachEntity.getId())).isEqualTo(teamCoachEntity);
    }

    @Test
    void delete() {
        TeamCoachEntity coachA = new TeamCoachEntity("AutistaCoachA");
        TeamCoachEntity coachB = new TeamCoachEntity("AutistaCoachB");
        coachDao.create(coachA);
        coachDao.create(coachB);
        coachDao.remove(coachA);
        var coaches = coachDao.findAll();
        Assertions.assertThat(coaches).hasSize(1).contains(coachB);
    }
}
