package cz.muni.fi.pa165.sampledata;

import cz.muni.fi.pa165.entity.PlayerEntity;
import cz.muni.fi.pa165.entity.TeamEntity;
import cz.muni.fi.pa165.enums.CountryEnum;
import cz.muni.fi.pa165.services.player.PlayerService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.time.LocalDate;

/**
 * Loads some sample data to populate the eshop database.
 *
 * @author Martin Kuba makub@ics.muni.cz
 */
@Component
@Transactional //transactions are handled on facade layer
public class SampleDataLoadingFacadeImpl implements SampleDataLoadingFacade {

    final static Logger log = LoggerFactory.getLogger(SampleDataLoadingFacadeImpl.class);

    @Autowired
    private PlayerService playerService;

    @Override
    @SuppressWarnings("unused")
    public void loadData() throws IOException {

        TeamEntity team = new TeamEntity();
        team.setName("Autisti");
        PlayerEntity crimsix = player("Ian Porter", LocalDate.of(1990,2,4), CountryEnum.AFGHANISTAN, team
        ,5,6,7);

        PlayerEntity JJoNak = player("Bang Seong-hyun ", LocalDate.of(1995,2,4), CountryEnum.AFGHANISTAN, team
                ,5,6,7);
        log.info("Loaded eShop orders.");
    }

    private PlayerEntity player(String name, LocalDate dateOfBirth, CountryEnum country, TeamEntity team,
                                int killStat, int deathStat, int assistStat) {
        PlayerEntity player = new PlayerEntity();
        player.setName(name);
        player.setDateOfBirth(dateOfBirth);
        player.setCountry(country);
        player.setTeam(team);
        player.setKillStat(killStat);
        player.setDeathStat(deathStat);
        player.setAssistStat(assistStat);
        playerService.create(player);
        return player;
    }

}
